@@ -10,8 +10,8 @@ use std::sync::atomic::Ordering::{self, AcqRel, Acquire, Relaxed, Release, SeqCs
 use std::sync::atomic::{AtomicBool, AtomicPtr, AtomicUsize};
 use std::sync::{Arc, Condvar, Mutex};
 use std::time::{Duration, Instant};
-use std::{fmt, io, ptr, usize};
-use std::{isize, mem, ops};
+use std::{fmt, io, ptr};
+use std::{mem, ops};
 use {sys, Token};
 
 // Poll is backed by two readiness queues. The first is a system readiness queue
@@ -1183,7 +1183,7 @@ impl Poll {
     }
 
     #[inline]
-    #[cfg_attr(feature = "clippy", allow(clippy::if_same_then_else))]
+    #[allow(clippy::if_same_then_else)]
     fn poll2(
         &self,
         events: &mut Events,
