@@ -81,7 +81,6 @@ impl Application {
                 | WindowEvent::PanGesture { .. }
                 | WindowEvent::HoveredFileCancelled
                 | WindowEvent::Destroyed
-                | WindowEvent::ThemeChanged(_)
                 | WindowEvent::HoveredFile(_)
                 | WindowEvent::Moved(_)
         )
@@ -129,7 +128,7 @@ impl ApplicationHandler<EventPayload> for Application {
         window.is_focused = true;
         self.router.create_route_from_window(window);
 
-        log::info!("Initialisation complete");
+        tracing::info!("Initialisation complete");
     }
 
     fn user_event(&mut self, event_loop: &ActiveEventLoop, event: EventPayload) {
