@@ -379,12 +379,9 @@ impl Screen<'_> {
     ) -> &mut Self {
         self.sugarloaf.rescale(new_scale);
         self.sugarloaf.resize(new_size.width, new_size.height);
-        // TODO: Fix this double render hack on scale update
         self.render();
         self.resize_all_contexts();
 
-        self.render();
-
         self
     }
 
@@ -460,7 +457,7 @@ impl Screen<'_> {
         let mods = self.modifiers.state();
 
         if is_kitty_keyboard_enabled && key.state == ElementState::Released {
-            if !mode.contains(Mode::KEYBOARD_REPORT_EVENT_TYPES)
+            if !mode.contains(Mode::REPORT_EVENT_TYPES)
                 || mode.contains(Mode::VI)
                 || self.search_active()
             {
@@ -479,7 +476,7 @@ impl Screen<'_> {
                 // NOTE: Echo the key back on release to follow kitty/foot behavior. When
                 // KEYBOARD_REPORT_ALL_KEYS_AS_ESC is used, we build proper escapes for
                 // the keys below.
-                _ if mode.contains(Mode::KEYBOARD_REPORT_ALL_KEYS_AS_ESC) => {
+                _ if mode.contains(Mode::REPORT_ALL_KEYS_AS_ESC) => {
                     crate::bindings::kitty_keyboard::build_key_sequence(key, mods, mode)
                         .into()
                 }
@@ -536,10 +533,10 @@ impl Screen<'_> {
             // 1. No keyboard input protocol is enabled.
             // 2. Mode is KEYBOARD_DISAMBIGUATE_ESC_CODES, but we have text + empty or Shift
             //    modifiers and the location of the key is not on the numpad, and it's not an `Esc`.
-            let write_legacy = !mode.contains(Mode::KEYBOARD_REPORT_ALL_KEYS_AS_ESC)
+            let write_legacy = !mode.contains(Mode::REPORT_ALL_KEYS_AS_ESC)
                 && !text.is_empty()
-                && (!mode.contains(Mode::KEYBOARD_DISAMBIGUATE_ESC_CODES)
-                    || (mode.contains(Mode::KEYBOARD_DISAMBIGUATE_ESC_CODES)
+                && (!mode.contains(Mode::DISAMBIGUATE_ESC_CODES)
+                    || (mode.contains(Mode::DISAMBIGUATE_ESC_CODES)
                         && (mods.is_empty() || mods == ModifiersState::SHIFT)
                         && key.location != KeyLocation::Numpad
                         // Special case escape here.
@@ -1279,16 +1276,20 @@ impl Screen<'_> {
             let main_fd = *self.ctx().current().main_fd;
             let shell_pid = &self.ctx().current().shell_pid;
             match teletypewriter::spawn_daemon(program, args, main_fd, *shell_pid) {
-                Ok(_) => log::debug!("Launched {} with args {:?}", program, args),
-                Err(_) => log::warn!("Unable to launch {} with args {:?}", program, args),
+                Ok(_) => tracing::debug!("Launched {} with args {:?}", program, args),
+                Err(_) => {
+                    tracing::warn!("Unable to launch {} with args {:?}", program, args)
+                }
             }
         }
 
         #[cfg(windows)]
         {
             match teletypewriter::spawn_daemon(program, args) {
-                Ok(_) => log::debug!("Launched {} with args {:?}", program, args),
-                Err(_) => log::warn!("Unable to launch {} with args {:?}", program, args),
+                Ok(_) => tracing::debug!("Launched {} with args {:?}", program, args),
+                Err(_) => {
+                    tracing::warn!("Unable to launch {} with args {:?}", program, args)
+                }
             }
         }
     }
