@@ -228,12 +228,12 @@ impl SugarloafLayout {
         let expected_stack_bound = (self.width / self.dimensions.scale)
             - (self.dimensions.width * self.dimensions.scale);
 
-        log::info!("expected columns {}", self.columns);
+        tracing::info!("expected columns {}", self.columns);
         if current_stack_bound < expected_stack_bound {
             let stack_difference = ((expected_stack_bound - current_stack_bound)
                 / (self.dimensions.width * self.dimensions.scale))
                 as usize;
-            log::info!("recalculating columns due to font width, adding more {stack_difference:?} columns");
+            tracing::info!("recalculating columns due to font width, adding more {stack_difference:?} columns");
             self.columns += stack_difference;
         }
 
@@ -241,7 +241,7 @@ impl SugarloafLayout {
             let stack_difference = ((current_stack_bound - expected_stack_bound)
                 / (self.dimensions.width * self.dimensions.scale))
                 as usize;
-            log::info!("recalculating columns due to font width, removing {stack_difference:?} columns");
+            tracing::info!("recalculating columns due to font width, removing {stack_difference:?} columns");
             self.columns -= stack_difference;
         }
     }
